<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="utf-8"
     omit-xml-declaration="yes" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
  />

  <xsl:template match="/"><!--Шаблон, применяемый к корневому элементу ("/")-->
    <html xmlns="http://www.w3.org/1999/xhtml"><!--Элементы, не начинающиеся с префикса 'xsl:' или других специальных префиксов, попадают прямо в содержимое конечного файла -->
      <head><!--В них используется обычный HTML -->
        <link rel="stylesheet" type="text/css" href="biblio.css"/>
      </head>
      <body>
        <h1>A Sample Bibliography</h1>
        <xsl:apply-templates select="*"/><!--Инструкция XSL: Вызов шаблонов для всех дочерних элементов корня-->
      </body>
    </html>
  </xsl:template>

  <xsl:template match="book"><!--Этот шаблон применяется к элементам 'book'-->
    <h2><!--Ссылка на каждую книгу будет начинаться с заголовка <h2>A book</h2>-->
      <a><!--В начале заголовка ставим закладку: <a name="..."></a>, чтобы можно было перейти на неё с помощью гиперссылки -->
        <xsl:attribute name="name"><!--Добавляем в элемент <a> атрибут 'name', значение которому присваиваем ниже инструкцией 'xsl:value-of' -->
          <xsl:value-of select="./@bookid"/><!--Берём название для закладки из значения атрибута 'bookid' текущего элемента-->
        </xsl:attribute>
      </a>A book
    </h2>
    <xsl:apply-templates select="*"/><!--Вызываем шаблоны для "детей" элемента 'book'-->
  </xsl:template>

  <xsl:template match="//book/*"><!--Этот шаблон применяется ко всем "детям" элемента "book"-->
    <p><!--Каждый дочерний элемент начинаем с нового абзаца-->
      <font color="blue">
        <xsl:value-of select="."/><!--Эта инструкция вписывает в конечный файл текстовое содержимое текущего (.) элемента-->
      </font>
    </p>
  </xsl:template>

  <xsl:template match="article"><!--Этот шаблон применяется к элементам "article"-->
    <h2>An article</h2>
    <h3>In a
      <a><!--Слово "book" оформляем как гиперссылку на закладку, которая находится при упоминании нужной книги. Имя для гиперссылки берём из атрибута 'bookref'-->
<!--Например, если книга имеет bookid='FRA001', то и закладка будет называться так же: <a name="FRA001"> -->
<!--Тогда гиперссылка на неё должна выглядеть так: <a href="#FRA001"> -->
        <xsl:attribute name="href">#<xsl:value-of select="./@bookref"/>
        </xsl:attribute>book
      </a>
    </h3>
    <xsl:apply-templates select="*"/>
  </xsl:template>

  <xsl:template match="//article/*"><!--Этот шаблон применяется ко всем "детям" элемента "article"-->
    <p>
      <font color="green">
        <xsl:value-of select="."/>
      </font>
    </p>
  </xsl:template>
</xsl:stylesheet>